processor

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package processor contains several implementations of the batch.Processor interface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Error

type Error struct {
	Err error
}

Error returns a Processor that returns an error while processing.

func (*Error) Process

func (p *Error) Process(ctx context.Context, ps *batch.PipelineStage)

Process discards all data sent to it after a certain amount of time.

type Nil

type Nil struct {
	Duration time.Duration
}

Nil is a Processor that discards all data after a specified duration. It can be used as a mock Processor.

func (*Nil) Process

func (p *Nil) Process(ctx context.Context, ps *batch.PipelineStage)

Process discards all data sent to it after a certain amount of time.

Jump to