Documentation
¶
Overview ¶
Package source contains several implementations of the batch.Source interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Channel ¶
type Channel struct {
Input <-chan interface{}
}
Channel is a Source that reads from input until it is closed. The input channel can be buffered or unbuffered.
type Error ¶
type Error struct {
Err error
}
Error is a Source that returns an error and then closes immediately. It can be used as a mock Source.
Click to show internal directories.
Click to hide internal directories.